@@ -495,13 +495,13 @@ class MainClass():
         path_3 = path_2["suffix"]
         return os.path.join(self.RootPath,path_1["path"],path_2["path"],code+'.'+path_3[fqt])
 
-    def get_k_data(self,code,start,end='',fqt="0",ktype='D'):
+    def get_hist_data(self,code,start,end='',fqt="0",ktype='D'):
         '''行情数据'''
         data_type = self._get_market(code)
         file_path = self._get_data_path(data_type,ktype,fqt,code)
         return self._do_something_data(file_path,start,end)
 
-    def get_IncomeStatement_data(self, code, start, end=''):
+    def income(self, code, start, end=''):
         '''
         非金融利润表数据
         :param code:
@@ -513,7 +513,7 @@ class MainClass():
         file_path = self._get_data_path(data_type, "finance", "0", code)
         return self._do_something_data(file_path, start, end,"1001")
 
-    def get_CashStatement_data(self, code, start, end=''):
+    def cashflow(self, code, start, end=''):
         '''
         非金融现金表数据
         :param code:
@@ -525,7 +525,7 @@ class MainClass():
         file_path = self._get_data_path(data_type, "finance", "0", code)
         return self._do_something_data(file_path, start, end, "1002")
 
-    def get_BalanceSheet_data(self, code, start, end=''):
+    def balancesheet(self, code, start, end=''):
         '''
         非金融资产负债表数据
         :param code:
@@ -537,7 +537,7 @@ class MainClass():
         file_path = self._get_data_path(data_type, "finance", "0", code)
         return self._do_something_data(file_path, start, end, "1003")
 
-    def get_Index_data(self, code,start,end='',fqt="0",ktype='D'):
+    def get_index(self, code,start,end='',fqt="0",ktype='D'):
         '''
         指数数据
         :param code:
@@ -549,8 +549,8 @@ class MainClass():
         return self._do_something_data(file_path, start, end)
 
     def get_stockIndex_data(self,code,base_code,start,end='',fqt="0",ktype='D',bFillNA=False):
-        k_data = self.get_k_data(code,start,end,fqt,ktype)
-        index_data = self.get_Index_data(base_code,start,end,fqt,ktype)
+        k_data = self.get_hist_data(code,start,end,fqt,ktype)
+        index_data = self.get_index(base_code,start,end,fqt,ktype)
         base_stock_data = index_data.loc[:, ['date', 'close']]
         base_stock_data.rename(columns={'close': 'base_close'}, inplace=True)
 
